@@ -86,7 +86,6 @@ def filter_bag(bags, out, bag_filter=Passthrough(), params=None, start_time=None
     num_generated = 0
 
     connection_filter = bag_filter.connection_filter
-    _stamp = rospy.Time(0)
     for topic, msg, stamp, connection_header, bag_tags in bags.read_messages(
             topics=topics, start_time=time_ranges, end_time=extra_time_ranges, return_connection_header=True,
             raw=bag_filter.is_raw, connection_filter=connection_filter, return_bag_tags=True):
@@ -96,7 +95,7 @@ def filter_bag(bags, out, bag_filter=Passthrough(), params=None, start_time=None
             msg = (msg[0], msg[1], msg[2], msg[4])
         heap.push((topic, msg, stamp, connection_header, {MessageTags.ORIGINAL}.union(bag_tags)))
         # For each bag message, process the whole heap up to the stamp of the bag message
-        while len(heap) > 0 and _stamp <= stamp:
+        while len(heap) > 0 and get_stamp_fn(heap.peek()) <= stamp:
             _topic, _msg, _stamp, _connection_header, tags = heap.pop()
             _connection_header = copy.copy(_connection_header)  # Prevent modifying connection records from in bag
             if extra_time_ranges is not None and time_ranges is not None:
